import {
  NButton,
  NSpace,
  useMessage,
  NForm,
  NFormItem,
  NSelect,
  NImage
} from 'naive-ui';
import { defineComponent, onMounted, reactive, ref } from 'vue';
import { getTrainingStudentDetail } from '../api';
import styles from '../index.module.less';
import trainType from '@/views/attend-class/model/train-type';
import defultHeade from '@/components/layout/images/teacherIcon.png';
import noSub from '../images/nosub.png';
import qualified from '../images/qualified.png';
import unqualified from '../images/unqualified.png';
import dayjs from 'dayjs';
export default defineComponent({
  props: {
    activeRow: {
      type: Object,
      default: () => ({ studentLessonTrainingId: '' })
    }
  },
  name: 'TrainingDetails',
  emits: ['close', 'getList'],
  setup(props, { emit }) {
    const data = reactive({
      uploading: false
    });
    const studnetInfo = ref({
      studentName: '',
      submitTime: '',
      trainingStatus: '',
      studentAvatar: '',
      studentLessonTrainingDetails: [] as any
    } as any);
    const message = useMessage();
    const foemsRef = ref();
    const getTrainingDetail = async () => {
      try {
        const res = await getTrainingStudentDetail({
          studentLessonTrainingId: props.activeRow.studentLessonTrainingId
        });

        studnetInfo.value = { ...res.data };
      } catch (e) {
        console.log(e);
      }
    };
    onMounted(() => {
      getTrainingDetail();
    });
    return () => (
      <div class={[styles.trainingDetails]}>
        <div class={styles.studentList}>
          <div class={styles.studentHeaderWrap}>
            <div class={styles.studentHeader}>
              <div class={styles.studentHeaderBorder}>
                <NImage
                  class={styles.studentHeaderImg}
                  src={
                    studnetInfo.value.studentAvatar
                      ? studnetInfo.value.studentAvatar
                      : defultHeade
                  }
                  previewDisabled></NImage>
              </div>
            </div>

            <div class={styles.workafterInfo}>
              <h4>
                {studnetInfo.value.studentName}{' '}
                <div class={styles.workafterInfoDot}>学生</div>
              </h4>
              <p>
                提交时间：
                {studnetInfo.value.submitTime
                  ? dayjs(new Date(studnetInfo.value.submitTime)).format(
                      'YYYY-MM-DD'
                    )
                  : '--'}
              </p>
            </div>
          </div>
          <NImage
            previewDisabled
            class={styles.workStatus}
            src={noSub}></NImage>
        </div>
        <div class={styles.workList}></div>
        <NSpace class={styles.btnGroup} justify="center">
          <NButton round onClick={() => emit('close')}>
            取消
          </NButton>
          <NButton round loading={data.uploading} type="primary">
            保存
          </NButton>
        </NSpace>
      </div>
    );
  }
});
